@@ -48,7 +48,7 @@ binmode(STDOUT, ":encoding(UTF-8)");
 binmode(STDIN,  ":encoding(UTF-8)");
 
 BEGIN {
-    our $VERSION = '1.27';
+    our $VERSION = '1.28';
 }
 
 sub ansi_output {
@@ -57,7 +57,6 @@ sub ansi_output {
 
 	if (length($text) > 1) {
 		while ($text =~ /\[\% (.*?) \%\]/) {
-			warn $1;
             while ($text =~ /\[\%\s+BOX (.*?),(\d+),(\d+),(\d+),(\d+),(.*?)\s+\%\](.*?)\[\%\s+ENDBOX\s+\%\]/i) {
                 my $replace = $self->box($1, $2, $3, $4, $5, $6, $7);
                 $text =~ s/\[\%\s+BOX.*?\%\].*?\[\%\s+ENDBOX.*?\%\]/$replace/i;
@@ -325,31 +324,12 @@ ANSI Encode
 A markup language to generate basic ANSI text
 This module is for use with the executable file
 
-=head1 AUTHOR & COPYRIGHT
-
-Richard Kelsch
-
- Copyright (C) 2025 Richard Kelsch
- All Rights Reserved
- Perl Artistic License
-
-This program is free software; you can redistribute it and/or modify it under the terms of the the Artistic License (2.0). You may obtain a copy of the full license at:
-
-L<http://www.perlfoundation.org/artistic_license_2_0>
-
-Any use, modification, and distribution of the Standard or Modified Versions is governed by this Artistic License. By using, modifying or distributing the Package, you accept this license. Do not use, modify, or distribute the Package, if you do not accept this license.
-
-If your Modified Version has been derived from a Modified Version made by someone other than you, you are nevertheless required to ensure that your Modified Version complies with the requirements of this license.
-
-This license does not grant you the right to use any trademark, service mark, tradename, or logo of the Copyright Holder.
-
-This license includes the non-exclusive, worldwide, free-of-charge patent license to make, have made, use, offer to sell, sell, import and otherwise transfer the Package with respect to any patent claims licensable by the Copyright Holder that are necessarily infringed by the Package. If you institute patent litigation (including a cross-claim or counterclaim) against any party alleging that the Package constitutes direct or contributory patent infringement, then this Artistic License to you shall terminate on the date that such litigation is filed.
-
-Disclaimer of Warranty: THE PACKAGE IS PROVIDED BY THE COPYRIGHT HOLDER AND CONTRIBUTORS "AS IS' AND WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES. THE IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, OR NON-INFRINGEMENT ARE DISCLAIMED TO THE EXTENT PERMITTED BY YOUR LOCAL LAW. UNLESS REQUIRED BY LAW, NO COPYRIGHT HOLDER OR CONTRIBUTOR WILL BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, OR CONSEQUENTIAL DAMAGES ARISING IN ANY WAY OUT OF THE USE OF THE PACKAGE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
-
 =head1 USAGE
 
  my $obj = Term::ANSIEncode->new();
+ $obj->output($string); # $string contains the markup to be converted and sent to STDOUT.
+
+See the manual for "ansi-encode" to use a script to load a file directly.
 
 Use this version for a full list of symbols:
  my $obj = Term::ANSIEncode->new('mode' => 'long');
@@ -370,6 +350,7 @@ Use this version for a full list of symbols:
 
 =head2 CURSOR
 
+ HOME        = Moves the cursor home to location 1,1.
  UP          = Moves cursor up one step
  DOWN        = Moves cursor down one step
  RIGHT       = Moves cursor right one step
@@ -465,4 +446,16 @@ Makes a solid blank line, the full width of the screen with the selected backgro
  HORIZONTAL RULE BRIGHT CYAN     = A solid line of bright cyan background
  HORIZONTAL RULE BRIGHT WHITE    = A solid line of bright white background
 
+=head1 AUTHOR & COPYRIGHT
+
+Richard Kelsch
+
+ Copyright (C) 2025 Richard Kelsch
+ All Rights Reserved
+ Perl Artistic License
+
+This program is free software; you can redistribute it and/or modify it under the terms of the the Artistic License (2.0). You may obtain a copy of the full license at:
+
+L<http://www.perlfoundation.org/artistic_license_2_0>
+
 =cut
